@@ -1,5 +1,4 @@
 import json
-import logging
 import os
 import platform
 import shlex
@@ -9,20 +8,9 @@ from dataclasses import dataclass
 from subprocess import Popen, PIPE, TimeoutExpired
 from typing import Any, Union
 
+import plogger
 from paramiko import SSHClient, ssh_exception, AutoAddPolicy
 
-logger_name = 'Plinux'
-logger = logging.getLogger(logger_name)
-logger.setLevel(logging.INFO)
-formatter = logging.Formatter(fmt='%(asctime)-15s | %(levelname)s | %(name)s | %(message)s',
-                              datefmt='%Y-%m-%d %H:%M:%S')
-
-# Console logger
-ch = logging.StreamHandler()
-ch.setLevel(logging.INFO)
-ch.setFormatter(formatter)
-logger.addHandler(ch)
-
 
 @dataclass
 class ResponseParser:
@@ -77,7 +65,7 @@ class Plinux:
         self.port = port
         self.username = username
         self.password = password
-        self.logger = logger
+        self.logger = plogger.logger(self.__class__.__name__)
         self.logger.disabled = not logger_enabled
 
     def __str__(self):
